@@ -71,8 +71,9 @@ namespace Imendio.Blam {
 	    this.HeadersVisible = false;
 
 	    // Sort the list
+	    channelSortFunc = new SortFunc (ChannelSortFunc);
 	    Utils.TreeSetSortFunc (this.Model.Handle, 1, 
-				   new SortFunc (ChannelSortFunc));
+				   channelSortFunc);
 	    ((ListStore)this.Model).SetSortColumnId (1, SortType.Ascending);	
 
 	    // Right click popup
@@ -108,7 +109,7 @@ namespace Imendio.Blam {
 	    ((ListStore)this.Model).AppendValues(channel, channel.Name, weight);
 	}
 
-	public Channel GetSelectedChannel ()
+	public Channel GetSelected ()
 	{
 	    TreeModel model;
 	    TreeIter  iter;
@@ -205,30 +206,31 @@ namespace Imendio.Blam {
 
 	private void EditChannelCb()
 	{
-	    EmitEditChannelEvent(GetSelectedChannel());
+	    EmitEditChannelEvent(GetSelected ());
 	}
 
 	private void MarkAsReadCb ()
 	{
 	    if (MarkChannelAsReadEvent != null) {
-		MarkChannelAsReadEvent (GetSelectedChannel ());
+		MarkChannelAsReadEvent (GetSelected ());
 	    }
 	}
 
 	private void RemoveChannelCb ()
 	{
 	    if (RemoveChannelEvent != null) {
-		RemoveChannelEvent (GetSelectedChannel ());
+		RemoveChannelEvent (GetSelected ());
 	    }
 	}
 	
 	private void UpdateChannelCb ()
 	{
 	    if (UpdateChannelEvent != null) {
-		UpdateChannelEvent (GetSelectedChannel ());
+		UpdateChannelEvent (GetSelected ());
 	    }
 	}
 	
+	private SortFunc channelSortFunc;
 	private int ChannelSortFunc (IntPtr a, IntPtr b)
 	{
 	    TreeIter iterA = TreeIter.New (a);
@@ -381,9 +383,12 @@ namespace Imendio.Blam {
 	[DllImport ("libblam.so")]
 	    static extern void   blam_channel_menu_destroy (IntPtr obj);
 
+        private CallbackHandler _holder;
+
 	public ChannelMenu()
 	{
-	    Handle = blam_channel_menu_new(new CallbackHandler(this.MenuCb));
+            _holder = new CallbackHandler (this.MenuCb);
+	    Handle = blam_channel_menu_new(_holder);
 	}
 
 	~ChannelMenu()
